==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiWidgets/QGraphicsSceneEvent_shell.cpp <==
#include "QGraphicsSceneEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(graphicsview)


void deleter_QGraphicsSceneEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGraphicsSceneEvent")
    QGraphicsSceneEvent *_ptr = reinterpret_cast<QGraphicsSceneEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QGraphicsSceneEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QGraphicsSceneEvent_shell) ); }

jmethodID QGraphicsSceneEvent_shell::__shell_javaMethod(int pos) const { return QGraphicsSceneEvent_shell::__shell()->javaMethod(typeid(QGraphicsSceneEvent), pos); }

// emitting (writeShellConstructor)
QGraphicsSceneEvent_shell::QGraphicsSceneEvent_shell(QEvent::Type type0)
    : QGraphicsSceneEvent(type0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QGraphicsSceneEvent::QGraphicsSceneEvent_shell(QEvent::Type type0)", QGraphicsSceneEvent_shell::__shell())
    QGraphicsSceneEvent_shell::__shell()->constructed(typeid(QGraphicsSceneEvent));
}

// emitting (writeShellDestructor)
QGraphicsSceneEvent_shell::~QGraphicsSceneEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QGraphicsSceneEvent::~QGraphicsSceneEvent()", QGraphicsSceneEvent_shell::__shell())
    QGraphicsSceneEvent_shell::__shell()->destructed(typeid(QGraphicsSceneEvent));
}

void QGraphicsSceneEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneEvent_shell*>(ptr)->QGraphicsSceneEvent_shell::__shell()->tryDeleteShell(typeid(QGraphicsSceneEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(graphicsview)

// emitting (writeConstructors)
// new QGraphicsSceneEvent(QEvent::Type)
void __qt_construct_QGraphicsSceneEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneEvent(QEvent::Type)")
#if QT_CONFIG(graphicsview)
    jobject type0 = __java_arguments[0].l;
    QEvent::Type __qt_type0 = qtjambi_cast<QEvent::Type>(__jni_env, type0);
    QGraphicsSceneEvent *__qt_this = new(__qtjambi_ptr) QGraphicsSceneEvent_shell(QEvent::Type(__qt_type0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// destruct QGraphicsSceneEvent_shell
void __qt_destruct_QGraphicsSceneEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGraphicsSceneEvent")

#if QT_CONFIG(graphicsview)

    reinterpret_cast<QGraphicsSceneEvent_shell*>(ptr)->~QGraphicsSceneEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(graphicsview)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGraphicsSceneEvent::QGraphicsSceneEvent(QEvent::Type)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneEvent_initialize_1native__Lio_qt_widgets_QGraphicsSceneEvent_2Lio_qt_core_QEvent_00024Type_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGraphicsSceneEvent::QGraphicsSceneEvent(QEvent::Type)")
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        jvalue arguments;
        arguments.l = type0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGraphicsSceneEvent_0, sizeof(QGraphicsSceneEvent_shell), typeid(QGraphicsSceneEvent), true, &deleter_QGraphicsSceneEvent, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(type0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneEvent::setWidget(QWidget*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneEvent_setWidget_1native_1QWidget_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID widget0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneEvent::setWidget(QWidget*)", __qt_this)
        QWidget* __qt_widget0 = QtJambiAPI::objectFromNativeId<QWidget>(widget0);
        __qt_this->setWidget(__qt_widget0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(widget0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneEvent::widget()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneEvent_widget_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneEvent::widget()const", __qt_this)
        QWidget* __qt_return_value = __qt_this->widget();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneEvent_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(graphicsview)

        QGraphicsSceneEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << __qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(graphicsview)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QGraphicsSceneEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(graphicsview)

    const std::type_info& typeId = registerObjectTypeInfo<QGraphicsSceneEvent>("QGraphicsSceneEvent", "io/qt/widgets/QGraphicsSceneEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QGraphicsSceneEvent, {
        ConstructorInfo(&__qt_construct_QGraphicsSceneEvent_0, "Lio/qt/core/QEvent$Type;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGraphicsSceneEvent);
    registerSizeOfShell(typeId, sizeof(QGraphicsSceneEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QGraphicsSceneEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(graphicsview)

}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QGraphicsSceneEvent_shell.cpp <==
#include "QGraphicsSceneEvent_shell.h"
#include <QtJambi/Cast>

#if QT_CONFIG(graphicsview)


void deleter_QGraphicsSceneEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QGraphicsSceneEvent")
    QGraphicsSceneEvent *_ptr = reinterpret_cast<QGraphicsSceneEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QGraphicsSceneEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QGraphicsSceneEvent_shell) ); }

jmethodID QGraphicsSceneEvent_shell::__shell_javaMethod(int pos) const { return QGraphicsSceneEvent_shell::__shell()->javaMethod(typeid(QGraphicsSceneEvent), pos); }

// emitting (writeShellConstructor)
QGraphicsSceneEvent_shell::QGraphicsSceneEvent_shell(QEvent::Type type0)
    : QGraphicsSceneEvent(type0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QGraphicsSceneEvent::QGraphicsSceneEvent_shell(QEvent::Type type0)", QGraphicsSceneEvent_shell::__shell())
    QGraphicsSceneEvent_shell::__shell()->constructed(typeid(QGraphicsSceneEvent));
}

// emitting (writeShellDestructor)
QGraphicsSceneEvent_shell::~QGraphicsSceneEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QGraphicsSceneEvent::~QGraphicsSceneEvent()", QGraphicsSceneEvent_shell::__shell())
    QGraphicsSceneEvent_shell::__shell()->destructed(typeid(QGraphicsSceneEvent));
}

void QGraphicsSceneEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QGraphicsSceneEvent_shell*>(ptr)->QGraphicsSceneEvent_shell::__shell()->tryDeleteShell(typeid(QGraphicsSceneEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)

#endif // QT_CONFIG(graphicsview)

// emitting (writeConstructors)
// new QGraphicsSceneEvent(QEvent::Type)
void __qt_construct_QGraphicsSceneEvent_QEvent_Type(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QGraphicsSceneEvent(QEvent::Type)")
#if QT_CONFIG(graphicsview)
    jobject type0 = __java_arguments[0].l;
    QEvent::Type __qt_type0 = qtjambi_cast<QEvent::Type>(__jni_env, type0);
    QGraphicsSceneEvent *__qt_this = new(__qtjambi_ptr) QGraphicsSceneEvent_shell(QEvent::Type(__qt_type0));
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
#else
    Q_UNUSED(__jni_object)
    Q_UNUSED(__java_arguments)
    Q_UNUSED(__qtjambi_ptr)
    Q_UNUSED(__qtjambi_is_generic)
    JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
}

// QGraphicsSceneEvent::QGraphicsSceneEvent(QEvent::Type)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneEvent_initialize_1native__Lio_qt_widgets_QGraphicsSceneEvent_2Lio_qt_core_QEvent_00024Type_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QGraphicsSceneEvent::QGraphicsSceneEvent(QEvent::Type)")
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        jvalue arguments;
        arguments.l = type0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QGraphicsSceneEvent_QEvent_Type, sizeof(QGraphicsSceneEvent_shell), typeid(QGraphicsSceneEvent), true, &deleter_QGraphicsSceneEvent, &arguments);
#else
        Q_UNUSED(__jni_object)
        Q_UNUSED(__jni_class)
        Q_UNUSED(type0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QGraphicsSceneEvent_shell
void __qt_destruct_QGraphicsSceneEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QGraphicsSceneEvent")

#if QT_CONFIG(graphicsview)

    reinterpret_cast<QGraphicsSceneEvent_shell*>(ptr)->~QGraphicsSceneEvent_shell();

#else
    Q_UNUSED(ptr)

#endif // QT_CONFIG(graphicsview)

}

// emitting  (functionsInTargetLang writeFinalFunction)
// QGraphicsSceneEvent::setWidget(QWidget*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneEvent_setWidget_1native_1QWidget_1ptr__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID widget0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        QGraphicsSceneEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneEvent::setWidget(QWidget*)", __qt_this)
        QWidget* __qt_widget0 = QtJambiAPI::objectFromNativeId<QWidget>(widget0);
        __qt_this->setWidget(__qt_widget0);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        Q_UNUSED(widget0)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QGraphicsSceneEvent::widget()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneEvent_widget_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
#if QT_CONFIG(graphicsview)
        const QGraphicsSceneEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGraphicsSceneEvent::widget()const", __qt_this)
        QWidget* __qt_return_value = __qt_this->widget();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
#else
        Q_UNUSED(__this)
        Q_UNUSED(__this_nativeId)
        JavaException::raiseQNoImplementationException(__jni_env, "The method has no implementation on this platform." QTJAMBI_STACKTRACEINFO );
#endif // QT_CONFIG(graphicsview)
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_widgets_QGraphicsSceneEvent_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {

#if QT_CONFIG(graphicsview)

        QGraphicsSceneEvent *__qt_this = QtJambiAPI::objectFromNativeId<QGraphicsSceneEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << __qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);

#else
        Q_UNUSED(__this_nativeId)
#endif // QT_CONFIG(graphicsview)

    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QGraphicsSceneEvent(){
    using namespace RegistryAPI;

#if QT_CONFIG(graphicsview)

    const std::type_info& typeId = registerObjectTypeInfo<QGraphicsSceneEvent>("QGraphicsSceneEvent", "io/qt/widgets/QGraphicsSceneEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QGraphicsSceneEvent, {
        ConstructorInfo(&__qt_construct_QGraphicsSceneEvent_QEvent_Type, "Lio/qt/core/QEvent$Type;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QGraphicsSceneEvent);
    registerSizeOfShell(typeId, sizeof(QGraphicsSceneEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QGraphicsSceneEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags

#endif //QT_CONFIG(graphicsview)

}
